Template for SC1, SC2, SC3 are in synapse in dreamtools synapse https://www.synapse.org/#!Synapse:syn4483180/wiki/


The file D9C1_template_sc1.gct.zip contains 1 file found on https://www.synapse.org/#!Synapse:syn2384331/wiki/64275

The file D9C1_template_sc2.zip and D9C1_template_sc3.zip contains2 files each (prection and feature) found in the same synapse page as above. Files were renamed for simplicity. Those should be the phase 3 version. 
